=========
Py Search
=========

This is a Python library of algorithms that implements various search
algorithms written by Christopher MacLellan (http://www.christopia.net).
In particular, there are uninformed, informed, and optimization techniques
implemented with a standard interface.

Installation
============

You can install this software using pip::

    pip install -U py_search

You can install the latest version of the code directly from github::
    
    pip install -U git+https://github.com/cmaclell/py_search@master

Important Links
===============

- Source code: `<https://github.com/cmaclell/py_search>`_
- Documentation: `<http://py_search.readthedocs.org>`_
